---
title: <span class="badge object-type-scalar"></span> VietnameseDong
---
# <span class="badge object-type-scalar"></span> VietnameseDong

Currency: Vietnamese Dong (VND)

## Definition

```python
# Currency: Vietnamese Dong (VND)
VietnameseDong: typing.Literal["currencyVND"] = "currencyVND"
```
